==> kafka-streams-5.3.0-ccs-test-sources.jar: org/apache/kafka/streams/state/internals/RocksDBTimestampedSegmentedBytesStoreTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.streams.state.internals;

import org.rocksdb.Options;

public class RocksDBTimestampedSegmentedBytesStoreTest
    extends AbstractRocksDBSegmentedBytesStoreTest<TimestampedSegment> {

    RocksDBTimestampedSegmentedBytesStore getBytesStore() {
        return new RocksDBTimestampedSegmentedBytesStore(
            storeName,
            "metrics-scope",
            retention,
            segmentInterval,
            schema
        );
    }

    @Override
    TimestampedSegments newSegments() {
        return new TimestampedSegments(storeName, retention, segmentInterval);
    }

    @Override
    Options getOptions(final TimestampedSegment segment) {
        return segment.getOptions();
    }
}

==> kafka-streams-5.4.3-ccs-test-sources.jar: org/apache/kafka/streams/state/internals/RocksDBTimestampedSegmentedBytesStoreTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.streams.state.internals;

import org.rocksdb.Options;

public class RocksDBTimestampedSegmentedBytesStoreTest
    extends AbstractRocksDBSegmentedBytesStoreTest<TimestampedSegment> {

    private final static String METRICS_SCOPE = "metrics-scope";

    RocksDBTimestampedSegmentedBytesStore getBytesStore() {
        return new RocksDBTimestampedSegmentedBytesStore(
            storeName,
            METRICS_SCOPE,
            retention,
            segmentInterval,
            schema
        );
    }

    @Override
    TimestampedSegments newSegments() {
        return new TimestampedSegments(storeName, METRICS_SCOPE, retention, segmentInterval);
    }

    @Override
    Options getOptions(final TimestampedSegment segment) {
        return segment.getOptions();
    }
}
